#delim ;
version 17.0;
*
 Create file mydocxdoc1.docx
 containing a .docx document
 with 2 versions of a docxtab table.
 SSC packages required:
 dolog sdecode ingap insingap xrewide docxtab
*;

clear all;
set linesize 96;

*
 Beginning of document-generating block
*;
local fname `"mydocxdoc1"';
tempname docxh1 docxf1;
putdocx begin, pagenum(decimal) pagesize(A4) 
  font("Times New Roman",12,black)
  header(`docxh1') footer(`docxf1');
cap n {;

*
 Add header
*;
putdocx paragraph, halign(left) font("Times New Roman",12,black)
  toheader(`docxh1');
putdocx text ("There should possibly be logos here..."),
  bold italic font("Times New Roman",12,black);

*
 Add footer
*;
putdocx paragraph, halign(left) font("Times New Roman",12,black)
  tofooter(`docxf1');
putdocx text (`"`fname'.docx"'), bold italic font("Courier New");
putdocx text (`", Page "'), bold italic font("Times New Roman",12,black);
putdocx pagenumber, bold italic font("Times New Roman",12,black);
putdocx text (" of "), bold italic font("Times New Roman",12,black);
putdocx pagenumber, totalpages bold italic font("Times New Roman",12,black);

*
 Output document title and subtitle
*;
putdocx paragraph, style(Heading1) font("Times New Roman","",black);
putdocx text (`"Regression of fuel consumption with respect to car weight in the "');
putdocx text ("xauto"), font("Courier New");
putdocx text (" data");

*
 Insert other document-populating commands
 using carriage return as the delimiter.
*;
#delim cr

putdocx paragraph, spacing(line, 12pt)
putdocx text ("In the dataset uploaded using the SSC package ")
putdocx text ("xauto"), font("Courier New")
putdocx textblock append
, we fitted a linear regression model 
of fuel consumption (in nipperkins per mile) 
with respect to car weight (in US tons), 
separately for the 2 car model origin groups 
(non-US models and US models). 
In each regression model, the regression slope was a weight effect on fuel consumption 
(expressed in nipperkins per additional ton-mile), 
and the intercept was a mean fuel consumption 
(expressed in nipperkins per mile) 
for a fantasy car with zero weight.
putdocx textblock end

#delim ;

*
 Input results
*;
use result1, clear;
desc, fu;
list, abbr(32);

*
 Section break for tables
*;
putdocx sectionbreak, landscape;

*
 Table 1.
*;
putdocx paragraph, style(Heading1) font("Times New Roman","",black);
putdocx text ("Table 1. Regression of fuel consumption with respect to weight (long version using ");
putdocx text ("insingap"), font("Courier New","",black);
putdocx text (")");

preserve;

* Decode row label and CI and P-value variables *;
sdecode modparam, gene(rowlab);
bmjcip estimate min* max* p, esub(none);
list us2 rowlab estimate min* max* p, noobs abbr(32);

*
 Assign variable characteristics:
 varname to contain header row,
 halign to contain horizontal alignment specifications.
*;
chardef rowlab estimate min* max* p, char(varname)
  val("Parameter" "Estimate" "(95%" "CI)" P);
chardef rowlab estimate min* max* p, char(halign)
  val("halign(left)" "halign(right)" "halign(right)" "halign(right)" "halign(left)");

* Insert gap rows for each car origin group *;
insingap us2, rowlabel(rowlab) grdecode(us2) suffix(:)
  gapind(gapobs) neword(rowseq);
list rowlab estimate min* max* p, noobs abbr(32) sepby(us2);

* Output table *;
docxtab rowlab estimate min* max* p, tablename(table1)
  layout(autofitcontents) border(all,single,black,0.5pt)
  headformat(bold italic shading(lightgray)) headchar(varname) tcolchar(halign)
  trowseq(tabrowseq);
* Make the gap rows bold with green shading *;
levelsof tabrowseq if gapobs, local(gaplist);
putdocx table table1(`gaplist',.), bold shading(236 236 236);

restore;

*
 Table 2.
*;
putdocx paragraph, style(Heading1);
putdocx paragraph, style(Heading1) font("Times New Roman","",black);
putdocx text ("Table 2. Regression of fuel consumption with respect to weight (wide version using ");
putdocx text ("xrewide"), font("Courier New","",black);
putdocx text (")");

preserve;

* Decode row label and CI and P-value variables *;
sdecode modparam, gene(rowlab);
bmjcip estimate min* max* p, esub(none);
list us2 rowlab estimate min* max* p, noobs abbr(32);

*
 Assign variable characteristics:
 varname2 to contain second header row,
 varname to contain header row,
 halign to contain horizontal alignment specifications.
*;
chardef rowlab min* max* p, char(varname2) val(" ");
chardef rowlab estimate min* max* p, char(varname)
  val("Parameter" "Estimate" "(95%" "CI)" P);
chardef rowlab estimate min* max* p, char(halign)
  val("halign(left)" "halign(right)" "halign(right)" "halign(right)" "halign(left)");

*
 Reformat table to wide,
 resetting characteristic varname2 for estimate variables
 to contain value labels for us2.
*;
xrewide estimate min* max* p, i(modparam rowlab) j(us2)
  cjlabel(varname2) vjlabel(estimate) sjlabel(:)
  lxjk(cellvars);

* Output table *;
docxtab rowlab `cellvars', tablename(table2)
  layout(autofitcontents) border(all,single,black,0.5pt)
  headformat(bold italic shading(lightgray)) headchar(varname2 varname) tcolchar(halign);

restore;


};
putdocx save `"`fname'.docx"', replace;
*
 End of document-generating block
*;

exit;
