#delim ;
version 17.0;
*
 Create files mymddoc1.md and mymddoc1.htm
 containing Markdown and HTML versions of a document
 with 2 versions of a listtab table.
 SSC packages required:
 dolog tfinsert sdecode ingap insingap xrewide listtab
*;

clear all;
set linesize 96;

*
 Input results
*;
use result1, clear;
desc, fu;
list, abbr(32);

*
 Beginning of document-generating block
*;
tempname mdb1;
sleep 1;
file open `mdb1' using `"mymddoc1.md"', write replace;
capture noisily {;

*
 Create introductory text using tfinsert
*;
#delim cr
tfinsert `mdb1', terminator(END_OF_MD)

<h1>Regression of fuel consumption with respect to car weight in the <tt>xauto</tt> data</h1>

In the dataset uploaded using the SSC package `xauto`,
we fitted a linear regression model
of fuel consumption (in nipperkins per mile)
with respect to car weight (in US tons),
separately for the 2 car model origin groups
(non-US models and US models).
In each regression model, the regression slope was a weight effect on fuel consumption
(expressed in nipperkins per additional ton-mile),
and the intercept was a mean fuel consumption
(expressed in nipperkins per mile)
for a fantasy car with zero weight.
END_OF_MD
#delim ;

*
 Table 1.
*;
file write `mdb1'
  _n "<h2>Table 1. Regression of fuel consumption with respect to weight (long version using <tt>insingap</tt>)</h2>"
  _n _n;
preserve;

* Decode row label and CI and P-value variables *;
sdecode modparam, gene(rowlab);
bmjcip estimate min* max* p, esub(htmlsuper);
list us2 rowlab estimate min* max* p, noobs abbr(32);

*
 Assign variable characteristics:
 varname to contain header row,
 halign to contain horizontal alignment row.
*;
chardef rowlab estimate min* max* p, char(varname)
  val("Parameter" "Estimate" "(95%" "CI)" P) prefix(*) suffix(*);
chardef rowlab estimate min* max* p, char(halign)
  val(":---" "---:" "---:" "---:" ":---");

* Insert gap rows for each car origin group *;
insingap us2, rowlabel(rowlab) grdecode(us2) prefix(**) suffix(:**)
  neword(rowseq);
list rowlab estimate min* max* p, noobs abbr(32) sepby(us2);

* Output table *;
listtab rowlab estimate min* max* p, handle(`mdb1') rstyle(markdown)
  headchar(varname halign) type;

restore;

*
 Table 2.
*;
file write `mdb1'
  _n "<h2>Table 2. Regression of fuel consumption with respect to weight (wide version using <tt>xrewide</tt>)</h2>"
  _n _n;
preserve;

* Decode row label and CI and P-value variables *;
sdecode modparam, gene(rowlab);
bmjcip estimate min* max* p, esub(htmlsuper);
list us2 rowlab estimate min* max* p, noobs abbr(32);

*
 Assign variable characteristics:
 varname2 to contain second header row,
 varname to contain header row,
 halign to contain horizontal alignment row.
*;
chardef rowlab min* max* p, char(varname2) val(" ");
chardef rowlab estimate min* max* p, char(varname)
  val("Parameter" "Estimate" "(95%" "CI)" P) prefix(*) suffix(*);
chardef rowlab estimate min* max* p, char(halign)
  val(":---" "---:" "---:" "---:" ":---");

*
 Reformat table to wide,
 resetting characteristic varname2 for estimate variables
 to contain value labels for us2.
*;
xrewide estimate min* max* p, i(modparam rowlab) j(us2)
  cjlabel(varname2) vjlabel(estimate) pjlabel(*) sjlabel(:*)
  lxjk(cellvars);

* Output table *;
listtab rowlab `cellvars', handle(`mdb1') rstyle(markdown)
  headchar(varname2 varname halign) type;

restore;

};
file close `mdb1';
*
 End of document-generating block
*;

*
 Convert Markdown document to HTML
*;
markdown mymddoc1.md, saving(mymddoc1.htm) replace;

exit;
